@@ -1,6 +1,10 @@
 """Command line script for J3."""
 import glob
 import importlib
+
+from uvicorn.supervisors.multiprocess import Multiprocess
+from j3.reloader import ChangeReloader
+import logging
 import os
 import sys
 from argparse import ArgumentParser, Namespace, RawTextHelpFormatter
@@ -14,6 +18,8 @@ import uvicorn
 from pkg_resources import resource_string
 from sqlalchemy.sql.schema import MetaData
 from starlette.routing import BaseRoute
+from uvicorn.config import Config
+from uvicorn.server import Server
 
 from j3.config import J3Config
 from j3.core import AbstractJ3, J3Error, J3InitError
@@ -49,14 +55,8 @@ class J3Command:
         """
         self.path = Path(os.path.abspath("."))
         self.msa = cast(J3Config, J3Config.load_from_config(self.path))
-
-        if self.msa.is_implicit_name:
-            # 앞에서 어떤 경우에도 이름을 못얻으면 현재 경로를 암시적으로
-            # 이름으로 정한다.
-            # self.print_warn(
-            #    f"app name is implicitly given as *{bold(self.msa.name)}* by the current path."
-            # )
-            ...
+        config_module_name = f"{self.msa.module_name}.config"
+        self.config_module = importlib.import_module(config_module_name)
 
     def print_warn(self, msg: str):
         print(f"{bold('J3 WARNING:', YELLOW)} {msg}")
@@ -73,11 +73,14 @@ class J3Command:
         """
         앱에서 오버라이드된 config.xxx 를 실행한다.
         """
-        self.banner("Configuration")
-        config_name = ns.config
-        module_name = self.msa.module_name + ".config." + config_name
-        module = importlib.import_module(module_name)
-        getattr(module, "run")()
+        config_banner = "J3 Configuration"
+        config_module_doc = self.config_module.__doc__.strip(".\n\t ")
+        module = importlib.import_module(self.msa.module_name + ".config." + ns.config)
+        if config_module_doc:
+            module_doc = " : " + bold(module.__doc__, CYAN) if module.__doc__ else ""
+            config_banner = f"⚙️  {bold(config_module_doc, YELLOW)}{module_doc}"
+        self.banner(config_banner)
+        getattr(module, "run")(self.msa)
 
     def init(self, force=False):
         """J3 앱 프로젝트 디렉토리를 권장 구조로 초기화 합니다."""
@@ -205,7 +208,28 @@ class J3Command:
                     uvicorn_init.write_text(
                         content + "\nfrom colorama import init; init()"
                     )
-            uvicorn.run(app_name, reload=reload, port=self.msa.get_api_port())
+            self._uvicon_run(app_name, reload=reload, port=self.msa.get_api_port())
+
+    def _uvicon_run(self, app, **kwargs) -> None:
+        config = Config(app, **kwargs)
+        server = Server(config=config)
+
+        if (config.reload or config.workers > 1) and not isinstance(app, str):
+            logger = logging.getLogger("uvicorn.error")
+            logger.warning(
+                "You must pass the application as an import string to enable 'reload' or "
+                "'workers'."
+            )
+            sys.exit(1)
+
+        if config.should_reload:
+            sock = config.bind_socket()
+            ChangeReloader(config, target=server.run, sockets=[sock]).run()
+        elif config.workers > 1:
+            sock = config.bind_socket()
+            Multiprocess(config, target=server.run, sockets=[sock]).run()
+        else:
+            server.run()
 
     def load_domain(self) -> list[type]:
         """도메인 클래스를 로드합니다.
@@ -281,7 +305,7 @@ class J3Command:
         return [
             r
             for r in routes
-            if r.endpoint.__module__.startswith(self.msa.module_name + ".routes")
+            if hasattr(r, 'endpoint') and r.endpoint.__module__.startswith(self.msa.module_name + ".routes")
         ]
 
     def load_msg_handlers(self, msa: Optional[AbstractJ3] = None) -> MessageHandlerMap:
